==> imio.migrator-1.34.tar.gz: imio.migrator-1.34/setup.py <==
# -*- coding: utf-8 -*-
"""Installer for the imio.migrator package."""

from setuptools import find_packages
from setuptools import setup


long_description = (
    open('README.rst').read() + '\n' + open('CHANGES.rst').read() + '\n')


setup(
    name='imio.migrator',
    version='1.34',
    description="Migration helper tool",
    long_description=long_description,
    # Get more from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 4.3",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
    ],
    keywords='migration helpers',
    author='IMIO',
    author_email='dev@imio.be',
    url='https://github.com/imio/imio.migrator',
    download_url='https://pypi.org/project/imio.migrator',
    license='GPL',
    packages=find_packages('src', exclude=['ez_setup']),
    namespace_packages=['imio', ],
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'Plone',
        'imio.helpers',
        'imio.pyutils>=0.20',
        'setuptools',
    ],
    extras_require={
        'test': [
            'plone.app.testing',
        ],
    },
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    """,
)

==> imio.migrator-1.37.tar.gz: imio.migrator-1.37/setup.py <==
# -*- coding: utf-8 -*-
"""Installer for the imio.migrator package."""

from setuptools import find_packages
from setuptools import setup


long_description = (
    open('README.rst').read() + '\n' + open('CHANGES.rst').read() + '\n')


setup(
    name='imio.migrator',
    version='1.37',
    description="Migration helper tool",
    long_description=long_description,
    # Get more from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 4.3",
        "License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
    ],
    keywords='migration helpers',
    author='IMIO',
    author_email='dev@imio.be',
    url='https://github.com/imio/imio.migrator',
    download_url='https://pypi.org/project/imio.migrator',
    license='GPL',
    packages=find_packages('src', exclude=['ez_setup']),
    namespace_packages=['imio', ],
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'Plone',
        'imio.helpers>=1.0.1',
        'imio.pyutils>=1.1.1',
        'setuptools',
    ],
    extras_require={
        'test': [
            'plone.app.testing',
        ],
    },
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    """,
)
